--Will return information about memory
--Also has free list stalls and lazy writes
--Script will take just over 4 minutes to run due to the WAITFOR

SELECT        object_name
			, counter_name
		    , cntr_value
			, CASE  WHEN counter_name = 'Page Reads/sec'		    THEN 'Some sources say should be below 90, but should review other counters'
					WHEN counter_name = 'Page Writes/sec'		    THEN 'Some sources say should be below 90, but should review other counters'
					WHEN counter_name = 'checkpoint Pages/sec'		THEN 'Should be low, but need to compare to a baseline'
					WHEN counter_name = 'Page life expectancy'		THEN 'PLE Should be above 300'
					WHEN counter_name = 'Target Server Memory (KB)' THEN 'How much memory SQL Server would like to use to operate efficiently'
					WHEN counter_name = 'Total Server Memory (KB)'  THEN 'Current amount of memory that SQL Server is using'
					WHEN counter_name = 'Memory Grants Pending'		THEN 'Memory grants pending should be 0'
    		  END  AS 'Note' 
			, CASE	WHEN counter_name = 'Page Reads/sec'		    THEN 'Some sources say should be below 90, but should review other counters'
					WHEN counter_name = 'Page Writes/sec'		    THEN 'Some sources say should be below 90, but should review other counters'
					WHEN counter_name = 'checkpoint Pages/sec'		THEN 'Should be low, but need to compare to a baseline'
					WHEN counter_name = 'Page life expectancy'		THEN 'If less than 300, dig deeper to find the cause'
					WHEN counter_name = 'Target Server Memory (KB)' THEN 'If Total Server memory is greater than Target Server memory, could be a sign of memory pressure'
					WHEN counter_name = 'Total Server Memory (KB)'  THEN 'If Total Server memory is greater than Target Server memory, could be a sign of memory pressure' 
					WHEN counter_name = 'Memory Grants Pending'		THEN 'Memory grants pending should be 0'
    		  END  AS 'Advise'
FROM sys.dm_os_performance_counters
WHERE counter_name IN (   'Page Life Expectancy'
						, 'Total Server Memory (KB)'
						, 'Target Server Memory (KB)'
						, 'Memory Grants Pending'
						, 'Checkpoint Pages/sec'
						, 'Page Writes/sec'
						, 'Page Reads/sec')
				AND instance_name = ''
ORDER BY counter_name

--Explain the difference between
-- Buffer cache hit ratio base
--and Buffer cache hit ratio
SELECT *
FROM sys.dm_os_performance_counters 
WHERE (counter_name = 'Buffer cache hit ratio base'
        AND OBJECT_NAME = 'SQLServer:Buffer Manager')
		OR (counter_name = 'Buffer cache hit ratio'
AND OBJECT_NAME = 'SQLServer:Buffer Manager')


--Do some math to get a percent
--Good Source
-----http://blogs.lessthandot.com/index.php/DataMgmt/DBAdmin/MSSQLServerAdmin/use-sys-dm_os_performance_counters-to-ge/

SELECT (main.cntr_value * 1.0 / base.cntr_value) * 100.0 as CacheHitRatio
FROM sys.dm_os_performance_counters  main
JOIN  (SELECT cntr_value,OBJECT_NAME 
    FROM sys.dm_os_performance_counters  
    WHERE counter_name = 'Buffer cache hit ratio base'
        AND OBJECT_NAME = 'SQLServer:Buffer Manager') base 
			ON  main.OBJECT_NAME = base.OBJECT_NAME
WHERE main.counter_name = 'Buffer cache hit ratio'
AND main.OBJECT_NAME = 'SQLServer:Buffer Manager'


--the number of requests for available database pages are suspended 
--requests stall because there are 
--no buffers available
--Should be 2 or less
	DECLARE @FLS BIGINT
	SELECT @FLS = cntr_value
	FROM sys.dm_os_performance_counters
	WHERE counter_name = 'Free list stalls/sec'

	WAITFOR DELAY '00:02:00';

	SELECT    'Free List Stalls/Sec' AS 'Status'
			, (cntr_value - @FLS) / 120  AS 'Free List Stalls/Sec'
			, 'Review LazyWrites, PLE and Memory Grants Pending if high, should be less than 2' AS 'Note'
	FROM sys.dm_os_performance_counters
	WHERE counter_name = 'Free list stalls/sec'



--Lazy Writer process is moving dirty pages from the buffer to disk in order to free up buffer space
--from the buffer to disk
--Should be as close to 0 as possible


--Average Per Second

	DECLARE @LazyWrites bigint;
	SELECT @LazyWrites = cntr_value
	FROM sys.dm_os_performance_counters
	WHERE counter_name = 'Lazy writes/sec';
 
	WAITFOR DELAY '00:02:00';

	SELECT   'Lazy Writes/Sec' AS 'Status'
		   , (cntr_value - @LazyWrites) / 120 AS 'LazyWrites/sec'
		   , 'Review Free List Stalls, PLE and Memory Grants Pending if high, should be close to Zero' AS 'Note'
	FROM sys.dm_os_performance_counters
	WHERE counter_name = 'Lazy writes/sec';


	
