
/*******************************************************/

--1aa

		PRINT '========================================================================================================================='
		PRINT ''
		PRINT ''
		PRINT 'Returns file information for each database'
		SET NOCOUNT ON

		PRINT ''
		PRINT ''
		PRINT ''
		CREATE TABLE #DBInfo
				( DBBame VARCHAR(128)
				, FileName VARCHAR(500))

		SET NOCOUNT ON	
		EXECUTE master.sys.sp_MSforeachdb 'USE [?] INSERT INTO #DBInfo SELECT       
				name
			, filename
				FROM dbo.sysfiles a '

		SELECT 'DB File Information - Location'  AS 'Setting'
				, CONVERT(VARCHAR(50),DBBame) AS 'Name'
				, FileName 
		FROM #DBInfo

		DROP TABLE #DBInfo


/*******************************************************/

--#1a
		DBCC FREEPROCCACHE
		DBCC FREESESSIONCACHE
		DBCC DROPCLEANBUFFERS 
		--Restart the service

	--Logical reads vs physical reads

		USE AdventureWorks2014

		SET STATISTICS IO ON

		SELECT *
		FROM person.address

		--Clustered Index and searching for a single value
		SELECT *
		FROM person.address
		WHERE AddressID = 1

		--Clustered Index and searching for multiple values
		SELECT *
		FROM person.address
		WHERE AddressID > 1


		--Non-Clustered Index 
		--Scan count should be 1
		SELECT *
		FROM person.address
		WHERE City = 'Chicago'

		--LOB Column
		SELECT    ProductPhotoID
				, LargePhoto
		FROM Production.ProductPhoto

		SELECT TOP 500000 * 
		FROM Sales.salesorderheader
		WHERE OrderDate < (SELECT '19961029');

		SET STATISTICS IO OFF

/*******************************************************/

--#1

		--Demo Min and Max memory settings using SSMS

			SELECT *
			FROM sys.configurations
			WHERE configuration_id IN ( '1543', '1544' )



/*******************************************************/
--#2


			SELECT counter_name
					, cntr_value AS 'CounterValue'
					, CASE WHEN counter_name = 'Page life expectancy'      THEN 'PLE Should be above 300'
							WHEN counter_name = 'Target Server Memory (KB)' THEN 'How much memory SQL Server would like to use to operate efficiently'
							WHEN counter_name = 'Total Server Memory (KB)'  THEN 'Current amount of memory that SQL Server is using'
						END  AS 'Note'
					, 'If Total Server memory is greater than Target Server memory, could be a sign of memory pressure' AS 'Advice'
			FROM sys.dm_os_performance_counters
			WHERE counter_name IN (  'Page Life Expectancy'
									, 'Total Server Memory (KB)'
									, 'Target Server Memory (KB)')
							AND instance_name = ''
			ORDER BY counter_name

		 
			--Should be zero
			SELECT    'Memory Grants Pending' AS 'Status'
					,  Counter_Name
					,  Instance_Name
					,  Cntr_value
					, 'Review LazyWrites, PLE and Free List Stalls if high, should be 0' AS 'Note'
			FROM sys.dm_os_performance_counters
			WHERE counter_name = 'Memory Grants pending'


			--the number of requests for available database pages are suspended 
			--requests stall because there are 
			--no buffers available
			--Should be 2 or less
			DECLARE @FLS BIGINT
			SELECT @FLS = cntr_value
			FROM sys.dm_os_performance_counters
			WHERE counter_name = 'Free list stalls/sec'

			WAITFOR DELAY '00:00:15';

			SELECT    'Free List Stalls/Sec' AS 'Status'
					, (cntr_value - @FLS) / 120  AS 'Free List Stalls/Sec'
					, 'Review LazyWrites, PLE and Memory Grants Pending if high, should be less than 2' AS 'Note'
			FROM sys.dm_os_performance_counters
			WHERE counter_name = 'Free list stalls/sec'



			--Lazy Writer process is moving dirty pages from the buffer to disk in order to free up buffer space
			--from the buffer to disk
			--Should be as close to 0 as possible


			--Average Per Second

			DECLARE @LazyWrites bigint;
			SELECT @LazyWrites = cntr_value
			FROM sys.dm_os_performance_counters
			WHERE counter_name = 'Lazy writes/sec';
 
			WAITFOR DELAY '00:00:15';
 
			SELECT   'Lazy Writes/Sec' AS 'Status'
					, (cntr_value - @LazyWrites) / 120 AS 'LazyWrites/sec'
					, 'Review Free List Stalls, PLE and Memory Grants Pending if high, should be close to Zero' AS 'Note'
			FROM sys.dm_os_performance_counters
			WHERE counter_name = 'Lazy writes/sec';


/****************************************************/

--#3a
		--Optimize for Ad Hoc Workloads
		--https://blog.sqlauthority.com/2017/10/20/sql-server-turn-optimize-ad-hoc-workloads/
		--Pinal Dave

		SELECT    AdHoc_Plan_MB
				, Total_Cache_MB,
				  CONVERT(BIGINT,AdHoc_Plan_MB)*100.0 / CONVERT(BIGINT,Total_Cache_MB) AS 'AdHoc %'
		FROM (
		SELECT  CONVERT(BIGINT,SUM(CASE
					WHEN objtype = 'adhoc'
					THEN CONVERT(BIGINT,size_in_bytes)
					ELSE 0 END)) / 1048576.0 AdHoc_Plan_MB,
				CONVERT(BIGINT,SUM(CONVERT(BIGINT,size_in_bytes))) / 1048576.0 Total_Cache_MB
		FROM sys.dm_exec_cached_plans) T

/****************************************************/

--#3
		--Determine Buffer Pool status
		SELECT    path
				, file_id
				, state
				, state_description
				, current_size_in_kb  
		FROM sys.dm_os_buffer_pool_extension_configuration;
		
		 --Add Buffer Pool Extension file
		 --Will fail first time, will need to change 3 to a 7
		ALTER SERVER CONFIGURATION 
		SET BUFFER POOL EXTENSION 
		ON (FILENAME = 'C:\BPE\Example.BPE', SIZE = 7 GB); 


		--Disable Buffer Pool
		ALTER SERVER CONFIGURATION   
		SET BUFFER POOL EXTENSION OFF; 




/**************************************************/
 
 --#4
		--Run one at a time
		DBCC freeproccache
		--Turn on Actual Execution Plan
		--Show properties of the operator
		--Use AdventureWorks2014

		SET STATISTICS TIME ON  
 		USE [AdventureWorks2014]

		SELECT  *
		FROM Sales.SalesOrderDetail
		ORDER BY ProductID


	-------------------------------
		DBCC freeproccache
		SELECT  *
		FROM Sales.SalesOrderDetail
		ORDER BY ProductID
		OPTION (MAXDOP 1)
		GO

		--Clean up step
		SET STATISTICS IO OFF
		DBCC freeproccache

/**************************************************/
 
 --#4a
			PRINT '========================================================================================================================='
			PRINT ''
			PRINT ''
			PRINT 'Get Activity By Hour, past 8 weeks, only for databases with transaction log backups'
			SET NOCOUNT ON
			PRINT ''
			PRINT ''
			PRINT ''
			SELECT 'Activity by Hour'  AS 'Setting',
					@@servername AS 'Server', 
					a.database_name,
					DATEPART(HOUR,a.backup_start_date) AS 'Hour',
					convert(int,AVG(CASE WHEN charindex('Monday',datename(weekday,a.backup_start_date)) > 0 then ceiling(a.backup_size/1000000.00) End))  as 'Mon_size(MB)',
					convert(int,AVG(CASE WHEN charindex('Tuesday',datename(weekday,a.backup_start_date)) > 0 then ceiling(a.backup_size/1000000.00) End)) as 'Tue_size(MB)',
					convert(int,AVG(CASE WHEN charindex('Wednesday',datename(weekday,a.backup_start_date)) > 0 then ceiling(a.backup_size/1000000.00) End)) as 'Wed_size(MB)',
					convert(int,AVG(CASE WHEN charindex('Thursday',datename(weekday,a.backup_start_date)) > 0 then ceiling(a.backup_size/1000000.00) End)) as 'Thu_size(MB)',
					convert(int,AVG(CASE WHEN charindex('Friday',datename(weekday,a.backup_start_date)) > 0 then ceiling(a.backup_size/1000000.00) End)) as 'Fri_size(MB)',
					convert(int,AVG(CASE WHEN charindex('Saturday',datename(weekday,a.backup_start_date)) > 0 then ceiling(a.backup_size/1000000.00) End)) as 'Sat_size(MB)',
					convert(int,AVG(CASE WHEN charindex('Sunday',datename(weekday,a.backup_start_date)) > 0 then ceiling(a.backup_size/1000000.00) End)) as 'Sun_size(MB)'
					,MIN(a.backup_start_date ) as 'From:'
					,MAX(a.backup_start_date ) as 'To:'
					,COUNT(*)
			FROM msdb.dbo.backupset a (NOLOCK)
			WHERE a.type = 'L' --log backups
				AND a.backup_start_date 
					BETWEEN DATEADD(WEEK, DATEDIFF(WEEK,0,GETDATE())-8 ,0) AND GETDATE() --8 WEEKs back
			GROUP BY a.database_name, 
				DATEPART(HOUR,a.backup_start_date)
			ORDER BY a.database_name, 
				DATEPART(HOUR,a.backup_start_date)

			IF @@Rowcount = 0
				BEGIN
					Select 'No Transaction Log backups are taking place' AS 'Status'
				END

/**************************************************/
 
 --#5

	--Just to make sure is off from previous demos
	    SET STATISTICS IO OFF
	--Single File
		USE Master
		GO

		--Declare Variables
		DECLARE @timestamp DATETIME
		DECLARE @backup VARCHAR(100)
		DECLARE @dbname VARCHAR(50)

		--Set Variables and build backup string
		--We use Getdate() with the timestamp because if the job runs more than once a day, there will not be any filename conflicts at the OS level
		SET @timestamp = GETDATE()
		SET @dbname = 'AdventureWorks2014'
		SET @backup = 'C:\Backups\' + @dbname + REPLACE(REPLACE(REPLACE(CONVERT(VARCHAR(30),@timestamp, 20), '-', ''), ':', ''), ' ','') + '.Bak'

		--Perform Backup
		BACKUP DATABASE @dbname
		TO DISK = @backup


	--Multiple Files

 		Use Master
		GO

		--Declare Variables
		DECLARE @timestamp DATETIME
		DECLARE @backup1   VARCHAR(100)
		DECLARE @backup2   VARCHAR(100)
		DECLARE @backup3   VARCHAR(100)
		DECLARE @backup4   VARCHAR(100)
		DECLARE @backup5   VARCHAR(100)
		DECLARE @dbname    VARCHAR(50)

		--Set Variables and build backup string
		--We use Getdate() with the timestamp because if the job runs more than once a day, there will not be any filename conflicts at the OS level
		SET @timestamp = GETDATE()
		SET @dbname = 'AdventureWorks2014'
		SET @backup1 = 'C:\Backups\' + @dbname + REPLACE(REPLACE(REPLACE(CONVERT(VARCHAR(30),@timestamp, 20), '-', ''), ':', ''), ' ','') + 'File1.Bak'
		SET @backup2 = 'C:\Backups\' + @dbname + REPLACE(REPLACE(REPLACE(CONVERT(VARCHAR(30),@timestamp, 20), '-', ''), ':', ''), ' ','') + 'File2.Bak'
		SET @backup3 = 'C:\Backups\' + @dbname + REPLACE(REPLACE(REPLACE(CONVERT(VARCHAR(30),@timestamp, 20), '-', ''), ':', ''), ' ','') + 'File3.Bak'
		SET @backup4 = 'C:\Backups\' + @dbname + REPLACE(REPLACE(REPLACE(CONVERT(VARCHAR(30),@timestamp, 20), '-', ''), ':', ''), ' ','') + 'File4.Bak'
		SET @backup5 = 'C:\Backups\' + @dbname + REPLACE(REPLACE(REPLACE(CONVERT(VARCHAR(30),@timestamp, 20), '-', ''), ':', ''), ' ','') + 'File5.Bak'
		--Perform Backup
		BACKUP DATABASE @dbname
		TO DISK = @backup1,
		   DISK = @backup2,
		   DISK = @backup3,
		   DISK = @backup4,
		   DISK = @backup5


 /**************************************************/
 
 --#6

		
		

		-- run in a new connection

		USE AdventureWorks2014

		BEGIN TRAN
		UPDATE Person.Person SET Suffix = 'B' 
		WHERE BusinessEntityID < 20

		--Make sure to rollback

		ROLLBACK

		USE AdventureWorks2014

		--Run with out the NOLOCK then with the NOLOCK
		--Notice Suffix is all "B"
		SELECT * 
		FROM Person.Person  WITH (NOLOCK)
		WHERE BusinessEntityID < 20

		SET TRANSACTION ISOLATION LEVEL READ UNCOMMITTED
		SELECT * 
		FROM Person.Person 
		WHERE BusinessEntityID< 20

		--Run this to show types of locks aquired
		--Move to excel and show number of X locks compared to number of rows modified
		sp_lock

		--Will not work because in range of current update
		SET TRANSACTION ISOLATION LEVEL READ COMMITTED
		SELECT * 
		FROM Person.Person  

		--Will work because not in range of the update
		--Notice Suffix is not a B
		SET TRANSACTION ISOLATION LEVEL READ COMMITTED
		SELECT * 
		FROM Person.Person  
		WHERE BusinessEntityID > 220

 /**************************************************/
 
 --#7

		--Open in one window
			USE AdventureWorks2014
			BEGIN TRAN
				UPDATE person.person
					SET FirstName = 'Dave'
			--Make sure to rollback
			ROLLBACK

		--Open in a second window
			USE AdventureWorks2014
			SELECT	  Firstname
					, Lastname
					, ModifiedDate
			FROM person.person

		--Run in this window

			sp_who2

			--Put proper SPID in place of '?'
			DBCC Inputbuffer(52)

 /**************************************************/
 
 --#7a
			DBCC TRACEON (1204, 1222) --Turn on for session

			DBCC TRACEON (1204, 1222, -1) --Turn on globally

			DBCC TRACESTATUS(-1)  --Returns status of traces that are turned on
									--also run in a second connection

			DBCC TRACEOFF (1204, 1222, -1);  --Turn off globally

			
			DBCC TRACEOFF (1204, 1222);  --Turn off for the session


 /**************************************************/
 
 --#8

		--Run the two scripts that start with 8
		--Make sure trace flags are enabled
		--Review SQL Logs


 --8a

		--Run in a seperate session

		USE AdventureWorks2014

		BEGIN TRAN
		UPDATE Person.Person SET Suffix = 'B' 
		WHERE BusinessEntityID < 20

		--Make sure to rollback

		ROLLBACK

		--====================================

		SELECT * FROM   sys.dm_tran_locks
		WHERE Resource_type = 'object'

		--Use to show number of row level Exclusive locks
		SELECT * FROM   sys.dm_tran_locks
		WHERE Resource_type = 'key'


		--Use to show find the objects involved

		USE Adventureworks2014
		SELECT *
		FROM sysobjects
		WHERE id = 1765581328

/***************************************************/


--#9

		--Both Queries return the same three records
		--Make sure Actual Execution Plan is turned on
		--Look at Execution Plan
		SELECT TOP 1000 [AddressID]
			  ,[AddressLine1]
			  ,[AddressLine2]
			  ,[City]
			  ,[StateProvinceID]
			  ,[PostalCode]
			  ,[SpatialLocation]
			  ,[rowguid]
			  ,[ModifiedDate]
		  FROM [AdventureWorks2014].[Person].[Address]
		  where AddressLine1 like '%1970%'

		--Query 2
		SELECT TOP 1000 [AddressID]
			  ,[AddressLine1]
			  ,[AddressLine2]
			  ,[City]
			  ,[StateProvinceID]
			  ,[PostalCode]
			  ,[SpatialLocation]
			  ,[rowguid]
			  ,[ModifiedDate]
		  FROM [AdventureWorks2014].[Person].[Address]
		  where AddressLine1 like '1970%'

/***************************************************/

--#10 and #11
	--Insert data and create fragmentation
	--Demo Idera Fragmentation Analyzer

		--Fragmentation for all database indexes
		SELECT DB_ID(database_id) AS 'DatabaseName',*
		FROM sys.dm_db_index_physical_stats (Null, NULL, NULL, NULL, NULL) i
		where avg_fragmentation_in_percent > 30 
		GO 


		--Run this for a specific database
		USE Adventureworks2014


		CREATE TABLE #TempTableRowCounts
					(SchemaName VARCHAR(50)
					 , TableName VARCHAR(200)
					 , TotalRowCOunt BIGINT)
				INSERT #TempTableRowCounts
					SELECT  SCHEMA_NAME(schema_id),
							t.name,
							SUM(p.[rows]) AS [TotalRowCount]
					FROM sys.tables AS t
						INNER JOIN sys.partitions AS p
							ON t.object_id = p.object_id
								--AND p.index_id IN ( 0, 1 )
					GROUP BY SCHEMA_NAME(schema_id), t.name;


		SELECT 
				  i.Database_ID
				, i.Object_id
				, s.name
				, i.Index_Id
				, i.partition_number
				, i.index_type_desc
				, r.TotalRowCOunt
				, i.avg_fragmentation_in_percent
		FROM sys.dm_db_index_physical_stats (Null, NULL, NULL, NULL, NULL) i
				INNER JOIN sysobjects s
					ON i.object_id = s.id
				LEFT OUTER JOIN #TempTableRowCounts r
					ON s.name = r.TableName COLLATE DATABASE_DEFAULT
		WHERE 
				avg_fragmentation_in_percent > 30  AND
				database_id = 16 --Include if looking for a specific database
		--order by avg_fragmentation_in_percent desc


		DROP TABLE #TempTableRowCounts
		GO 
		
		--==============================================

		TRUNCATE TABLE [dbo].[TestFragmentation]


		--Then run the fragmentation code to confirm fragmentation is  empty
		SELECT COUNT(*) 
		FROM [dbo].[TestFragmentation]


		--Run this code to create fragmentation
		--Stop after a few minutes
		DECLARE @counter SMALLINT;  
		SET @counter = 1;  
		WHILE @counter < 10000
		   BEGIN  
			INSERT TestFragmentation
				(ID, TestFragString)
				Values
				( @counter
				  , CONVERT(varchar(255), NEWID()))
			  SET @counter = @counter + 1  
		   END;  
		GO 
		--Then run the code to confirm fragmentation NOT 0

		--Returns Fragementation percent
		SELECT a.index_id, name, avg_fragmentation_in_percent  
		FROM sys.dm_db_index_physical_stats (DB_ID(N'AdventureWorks2014'), 
				OBJECT_ID(N'dbo.TestFragmentation'), NULL, NULL, NULL) AS a  
			INNER JOIN sys.indexes AS b 
				ON a.object_id = b.object_id 
					AND a.index_id = b.index_id;  

			--Defrag All Indexes on a table
			--After each, run the above fragmentation percent query
			ALTER INDEX ALL ON dbo.testfragmentation 
			REORGANIZE ;   
			GO  

			ALTER INDEX ALL ON dbo.testfragmentation 
			REBUILD ;   
			GO 

			--Defrag for a specific index
			ALTER INDEX [NonClusteredIndex-20180503-225313] ON [dbo].[TestFragmentation]
			REBUILD;

			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                
/***************************************************/

--#11

	--See above


/***************************************************/

--#12

	--Demo the Query Store reports
	--Demo that is doesnt appear until enabled
	--Demo sample reports using the AdventureWorksDW2014 database

/***************************************************/

--#12a

		USE wideworldimporters
		SELECT * 
		FROM sys.database_automatic_tuning_options 


		ALTER DATABASE wideworldimporters
		SET AUTOMATIC_TUNING ( FORCE_LAST_GOOD_PLAN = ON ); 

		ALTER DATABASE wideworldimporters
		SET AUTOMATIC_TUNING ( FORCE_LAST_GOOD_PLAN = OFF ); 



/***************************************************/

--#12b

		--Turn on Execution plan
		--Select the query only
	
USE AdventureWorks2014

		 --Merge Join
		 --Run this with the Plan Guide Disabled
		 --Enable the plan guide
		 --Run it again
SELECT * 
FROM Sales.Customer AS c
INNER JOIN Sales.Customer AS ca 
	ON c.CustomerID = ca.CustomerID
		WHERE ca.TerritoryID = 5

		--Will not use the plan guide
		--Hint...at the end
SELECT * 
FROM Sales.Customer AS c
INNER JOIN Sales.Customer AS ca 
	ON c.CustomerID = ca.CustomerID
		WHERE ca.TerritoryID = 5

/***************************************************/

--#13

		USE AdventureWorks2014;  
		GO  
		DBCC SHOWCONTIG ('HumanResources.Employee');  
		GO  

		USE AdventureWorks2014;  
		GO  
		DBCC SHOWCONTIG ('HumanResources.Employee') WIth FAST;  
		GO 
		
		--Compare Rows and Rows Sampled
		--Go over "All Density"
		--Will demo more statistics related items later
		DBCC SHOW_STATISTICS ("Person.Address", AK_Address_rowguid);  
		GO 

		--Similar to sp_who2
		SELECT * FROM sysprocesses

/***************************************************/

--#13a

		--Counter Types

		SELECT	  object_name
				, counter_name
				, instance_name
				, cntr_value
				, cntr_type
				,  CASE cntr_type 
						WHEN 65792 THEN 'Absolute Meaning, number of times the counter event happened' 
						WHEN 272696576 THEN 'Per Second counter and is Cumulative in Nature'
				   END AS counter_comments
		FROM sys.dm_os_performance_counters
		WHERE cntr_type  in (65792, 272696576)

/***************************************************/

--#13b


		--If high could be an indicator
		SELECT *
		FROM sys.dm_os_performance_counters
		WHERE counter_name IN ('Page Splits/sec')
		ORDER BY counter_name

		SELECT *
		FROM sys.dm_os_performance_counters
		WHERE counter_name IN('Batch Requests/sec', 'SQL Compilations/sec', 'SQL Re-Compilations/sec')


/***************************************************/

--#14

	--Demo Activity Monitor in SSMS
	--Demo live queries
	--Demo how to get the execution plans

		USE AdventureWorks2014

		SELECT * 
		FROM Production.TransactionHistory th
			INNER JOIN Production.TransactionHistoryArchive tha 
					ON th.Quantity = tha.Quantity

		SELECT *
		FROM [Production].[Product]
			CROSS JOIN [Production].[ProductPhoto]
			CROSS JOIN [Sales].[SalesOrderDetail]

/***************************************************/

--#15

	--Demo Performance reports
	--Demo Server level dashboard
	--Demo Database level Transaction Analysis Overview



/***************************************************/

