/**************************************************************************
	Demo from a post on sqlperformance.com by Aaron Bertrand
	https://sqlperformance.com/2017/06/sql-plan/performance-myths-oversizing-strings
*************************************************************************/
--Demo to create tables	
		CREATE TABLE dbo.Email_V320
		(
		  id int IDENTITY PRIMARY KEY, email varchar(320)
		);
 
		CREATE TABLE dbo.Email_V1000
		( 
		  id int IDENTITY PRIMARY KEY, email varchar(1000)
		);
 
		CREATE TABLE dbo.Email_V4000
		(
		  id int IDENTITY PRIMARY KEY, email varchar(4000)
		);
 
		CREATE TABLE dbo.Email_Vmax
		(
		  id int IDENTITY PRIMARY KEY, email varchar(max)
		);


/*************************************************************************/
--Demo to insert date	


			INSERT dbo.Email_V320(email) SELECT TOP (10000) 
			  REPLACE(LEFT(LEFT(c.name, 64) + '@' + LEFT(o.name, 128) + '.com', 254), ' ', '')
			  FROM sys.all_columns AS c
			  INNER JOIN sys.all_objects AS o
			  ON c.[object_id] = o.[object_id]
			  INNER JOIN sys.all_columns AS c2
			  ON c.[object_id] = c2.[object_id]
			  ORDER BY NEWID();
 
			INSERT dbo.Email_V1000(email) SELECT email FROM dbo.Email_V320;
			INSERT dbo.Email_V4000(email) SELECT email FROM dbo.Email_V320;
			INSERT dbo.Email_Vmax (email) SELECT email FROM dbo.Email_V320;
 
			-- let's rebuild
			ALTER INDEX ALL ON dbo.Email_V320  REBUILD;
			ALTER INDEX ALL ON dbo.Email_V1000 REBUILD;
			ALTER INDEX ALL ON dbo.Email_V4000 REBUILD;
			ALTER INDEX ALL ON dbo.Email_Vmax  REBUILD;


/*************************************************************************/
--Demo to that the average length and max length are the same for all tables

		SELECT AVG(LEN(email)), MAX(LEN(email)) FROM dbo.Email_v320;
		SELECT AVG(LEN(email)), MAX(LEN(email)) FROM dbo.Email_v1000;
		SELECT AVG(LEN(email)), MAX(LEN(email)) FROM dbo.Email_v4000;
		SELECT AVG(LEN(email)), MAX(LEN(email)) FROM dbo.Email_vMAX;


/*************************************************************************/
--Demo to show data page allocations

		SELECT o.name, COUNT(p.[object_id])
		  FROM sys.objects AS o
		  CROSS APPLY sys.dm_db_database_page_allocations
			(DB_ID(), o.object_id, 1, NULL, 'LIMITED') AS p
		  WHERE o.name LIKE N'Email[_]V[^2]%'
		  GROUP BY o.name;

/*************************************************************************/
--Demo to show same number of records
--No memory warning

		SELECT id, email FROM dbo.Email_v320;
		SELECT id, email FROM dbo.Email_v1000;
		SELECT id, email FROM dbo.Email_v4000;
		SELECT id, email FROM dbo.Email_vMax;



/*************************************************************************/
--Demo for Memory warning
--Show memory grants in SELECT operator

		SELECT /* V<size>  */ ROW_NUMBER() OVER (PARTITION BY email ORDER BY email DESC), 
			email, REVERSE(email), SUBSTRING(email, 1, CHARINDEX('@', email)) 
		  FROM dbo.Email_V320 
		  GROUP BY REVERSE(email), email, SUBSTRING(email, 1, CHARINDEX('@', email))  
		  ORDER BY REVERSE(email), email;

		  SELECT /* V<size>  */ ROW_NUMBER() OVER (PARTITION BY email ORDER BY email DESC), 
			email, REVERSE(email), SUBSTRING(email, 1, CHARINDEX('@', email)) 
		  FROM dbo.Email_V1000 
		  GROUP BY REVERSE(email), email, SUBSTRING(email, 1, CHARINDEX('@', email))  
		  ORDER BY REVERSE(email), email;

		  SELECT /* V<size>  */ ROW_NUMBER() OVER (PARTITION BY email ORDER BY email DESC), 
			email, REVERSE(email), SUBSTRING(email, 1, CHARINDEX('@', email)) 
		  FROM dbo.Email_V4000 
		  GROUP BY REVERSE(email), email, SUBSTRING(email, 1, CHARINDEX('@', email))  
		  ORDER BY REVERSE(email), email;

		  SELECT /* V<size>  */ ROW_NUMBER() OVER (PARTITION BY email ORDER BY email DESC), 
			email, REVERSE(email), SUBSTRING(email, 1, CHARINDEX('@', email)) 
		  FROM dbo.Email_VMax 
		  GROUP BY REVERSE(email), email, SUBSTRING(email, 1, CHARINDEX('@', email))  
		  ORDER BY REVERSE(email), email;